Pillow
======

Python Imaging Library (Fork)
-----------------------------

Pillow is the "friendly PIL fork" by `Alex Clark and Contributors <https://github.com/python-pillow/Pillow/graphs/contributors>`_. PIL is the Python Imaging Library by Fredrik Lundh and Contributors.

.. image:: https://travis-ci.org/python-pillow/Pillow.svg?branch=master
   :target: https://travis-ci.org/python-pillow/Pillow
   :alt: Travis CI build status (Linux)

.. image:: https://travis-ci.org/python-pillow/pillow-wheels.svg?branch=latest
   :target: https://travis-ci.org/python-pillow/pillow-wheels
   :alt: Travis CI build status (OS X)
   
.. image:: https://pypip.in/v/Pillow/badge.png
    :target: https://pypi.python.org/pypi/Pillow/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/Pillow/badge.png
    :target: https://pypi.python.org/pypi/Pillow/
    :alt: Number of PyPI downloads

.. image:: https://coveralls.io/repos/python-pillow/Pillow/badge.png?branch=master
  :target: https://coveralls.io/r/python-pillow/Pillow?branch=master
   :alt: Code coverage

.. image:: https://landscape.io/github/python-pillow/Pillow/master/landscape.png
   :target: https://landscape.io/github/python-pillow/Pillow/master
   :alt: Code health

More Information
----------------

- `Changelog <https://github.com/python-pillow/Pillow/blob/master/CHANGES.rst>`_

  - `Pre-fork <https://github.com/python-pillow/Pillow/blob/master/CHANGES.rst#02b5---117-1995-2010>`_

- `Contribute <https://github.com/python-pillow/Pillow/blob/master/CONTRIBUTING.md>`_

  - `Issues <https://github.com/python-pillow/Pillow/issues>`_

- `Documentation <http://pillow.readthedocs.org/>`_

  - `About <http://pillow.readthedocs.org/about.html>`_
  - `Guides <http://pillow.readthedocs.org/guides.html>`_
  - `Installation <http://pillow.readthedocs.org/installation.html>`_
  - `Reference <http://pillow.readthedocs.org/reference/index.html>`_
